#
# spec file for package breezy
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define rustflags '-Clink-arg=-Wl,-z,relro,-z,now'

Name:           breezy
Version:        3.3.9
Release:        1.2
Summary:        Distributed version control system with multi-format support
License:        GPL-2.0-or-later
URL:            https://www.breezy-vcs.org/
Source0:        https://files.pythonhosted.org/packages/source/b/breezy/breezy-%{version}.tar.gz
Source98:       vendor-lib-rio.tar.xz
Source99:       vendor.tar.zst
BuildRequires:  cargo >= 1.41.0
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
# full stdlib for sqlite3
BuildRequires:  python3
BuildRequires:  python3-Cython
BuildRequires:  python3-PyYAML
BuildRequires:  python3-devel
BuildRequires:  python3-merge3
BuildRequires:  python3-pip
BuildRequires:  python3-setuptools
BuildRequires:  python3-setuptools-gettext
BuildRequires:  python3-setuptools-rust
BuildRequires:  python3-tzlocal
BuildRequires:  python3-wheel
BuildRequires:  rust >= 1.41.0
BuildRequires:  zstd
Requires:       python3-PyYAML
Requires:       python3-configobj
Requires:       python3-dulwich >= 0.19.11
Requires:       python3-fastbencode
Requires:       python3-merge3
Requires:       python3-patiencediff
Requires:       python3-tzlocal
Requires:       python3-urllib3 >= 1.24.1
Recommends:     python3-launchpadlib >= 1.6.3
Provides:       bzr = %{version}
Obsoletes:      bzr < %{version}
# SECTION test requirements
BuildRequires:  python3-configobj
BuildRequires:  python3-dulwich >= 0.19.11
BuildRequires:  python3-fastbencode
BuildRequires:  python3-fixtures >= 1.3.0
BuildRequires:  python3-patiencediff
BuildRequires:  python3-python-subunit
BuildRequires:  python3-testtools
# /SECTION

%description
Breezy is a version control system implemented in Python with
multi-format support. Breezy has built-in support for the Git and
Bazaar file formats and network protocols.

%prep
%autosetup -p1 -a 98 -a 99 -n breezy-%{version}

sed -ie "s,man/man1,share/man/man1," setup.py

sed -i '1{\@^#!i[[:blank:]]*%{_bindir}/env python@d}' \
    breezy/dirty_tracker.py \
    breezy/tests/ssl_certs/create_ssls.py \
    breezy/tests/test_dirty_tracker.py

%build
export RUSTFLAGS=%{rustflags}
export CFLAGS="%{optflags} -fno-strict-aliasing"
%python3_build

%install
export RUSTFLAGS=%{rustflags}
%python3_install
%fdupes %{buildroot}%{python3_sitearch}

# backwards compatible symbolic links
ln -s brz %{buildroot}%{_bindir}/bzr
echo ".so man1/brz.1" > %{buildroot}%{_mandir}/man1/bzr.1

%check
export PYTHONPATH=%{buildroot}%{python3_sitearch}
export LANG=en_US.UTF8
# log_C log_BOGUS - borked with py3.8+ as you can't change encoding
# test_ancient_{ctime,mtime} - broken on aarch64 %%arm ppc ppc64le
# test_distant_{ctime,mtime} - broken on %%arm
# test_plugins lp#1927523
# test_simple_local_git - pulls in forbidden modules with 3.10+
%{buildroot}%{_bindir}/bzr selftest -v --parallel=fork \
  -Oselftest.timeout=6000 -x bash_completion \
  -x breezy.tests.test_transport.TestSSHConnections.test_bzr_connect_to_bzr_ssh -x test_export_pot \
  -x test_log_C -x test_log_BOGUS \
%ifnarch %{ix86} x86_64 ppc64
  -x breezy.tests.test__dirstate_helpers.TestPackStat.test_ancient_ctime \
  -x breezy.tests.test__dirstate_helpers.TestPackStat.test_ancient_mtime \
%endif
%ifarch %{arm}
  -x breezy.tests.test__dirstate_helpers.TestPackStat.test_distant_ctime \
  -x breezy.tests.test__dirstate_helpers.TestPackStat.test_distant_mtime \
%endif
  -x breezy.tests.test_xml.TestSerializer.test_revision_text_v8 \
  -x breezy.tests.test_xml.TestSerializer.test_revision_text_v7 \
  -x breezy.tests.test_xml.TestSerializer.test_revision_text_v6 \
  -x breezy.tests.test_plugins.TestPlugins \
  -x breezy.tests.test_plugins.TestLoadingPlugins.test_plugin_with_error \
  -x breezy.tests.test_import_tariff.TestImportTariffs.test_simple_local_git

%files
%doc NEWS README.rst
%license COPYING.txt
%{_bindir}/bzr-receive-pack
%{_bindir}/bzr-upload-pack
%{_bindir}/git-remote-bzr
%{_bindir}/brz
%{_bindir}/bzr
%{python3_sitearch}/breezy*
%{_mandir}/man1/brz.1%{?ext_man}
%{_mandir}/man1/bzr.1%{?ext_man}
%{_mandir}/man1/git-remote-bzr.1%{?ext_man}
%dir %{_datadir}/locale/{ckb,fo,ku,my,sco}
%dir %{_datadir}/locale/{ckb,fo,ku,my,sco}/LC_MESSAGES
%{_datadir}/locale/*/*/breezy.mo

%changelog
* Thu Nov  7 2024 Matej Cepl <mcepl@cepl.eu>
- Update to 3.3.9:
  - Plenty of bug fixes
  - Compatibility up to 3.12
  - Add MergeProposal.__str__, MergeProposal.__repr__
  - Explicitly track which URLs are used for GitLab
- Add functional _service file.
- python-launchpadlib should be Recommends, not Suggests.
- Remove cargo_config (it is now included in the vendor tarball).
* Tue Oct 10 2023 Matej Cepl <mcepl@cepl.eu>
- Update to 3.3.4:
  - Improve handling of lp: URLs when lp: insteadOf is set in gitconfig.
  - Allow setting _ConnectRequestor.selector.
  - Fix brz-email bug on Python 3.
  - Fix compatibility with newer versions of dulwich.
* Wed Jun  7 2023 Matej Cepl <mcepl@suse.com>
- Update to 3.3.3:
  - Plenty of bug fixes
  - Drop support for the ubuntu: and debianlp: aliases.
    These imports have long been broken.
  - Fix support for newer versions of Dulwich.
  - Update Git code to use newer Dulwich APIs for pack generation,
    significantly improving performance.
- Remove upstreamed patch skip_lp2003710.patch.
* Mon Jan 23 2023 Matej Cepl <mcepl@suse.com>
- Update to 3.3.2:
  - Add --recurse-nested argument to 'brz export'.
  - Add an ``extra`` for installing PGP dependencies.
  - Convert multiple authors to the Co-authored-by field.
  - github: Lazily load github pull requests, improving   performance.
  - github: Return canonical URLs for branches.
  - Avoid deprecated distutils.version, ahead of removal.
  - Add a docker file.
  - launchpad: Store Launchpad credentials in authentication.conf.
  - git: Support accessing git branch configuration.
  - pgp: Add support for create_signatures=when-possible
  - propose: By default, don't push tags when proposing changes.
  - git: Split out and separately report ProtectedBranchHookDeclined.
  - git: Avoid reading entire pack files into memory.
  - Numerous bug fixes
- Remove upstreamed patches:
  - skip_resource.setrlimit.patch
- Add skip_lp2003710.patch to skip failing tests (lp#2003710).
* Mon Oct 24 2022 Jan Engelhardt <jengelh@inai.de>
- Remove silly wording from description
* Mon Jun 20 2022 Steve Kowalik <steven.kowalik@suse.com>
- Update to 3.2.2:
  * Breezy now relies on an external fastbencode Python module.
  * Basic support for nested trees in Git repositories, in the form
    of Git submodules.
- Add fastbencode to {Build,}Requires.
- No longer skip a test that passes, and add another broken one.
* Tue May 10 2022 Steve Kowalik <steven.kowalik@suse.com>
- Remove unneeded {Build,}Requires on python3-six.
* Wed Jul 14 2021 Matej Cepl <mcepl@suse.com>
- Update to 3.2.1:
  - Fix compatibliity with newer versions of Dulwich.
* Thu May  6 2021 Matej Cepl <mcepl@suse.com>
- Update to 3.2.0.
- Removed upstreamed patches:
  - 0001-Fix-tests-with-newer-dulwich.patch
  - 0002-Fix-more-tests.patch
  - 7531_7530.diff
  - 7551_7550.diff
- Skip failing tests mentioned in lp#1927523.
* Sun Dec  6 2020 Benjamin Greiner <code@bnavigator.de>
- Require the full python3 stdlib for sqlite3 import
  gh#openSUSE/python-rpm-macros#66
* Fri Dec  4 2020 Matej Cepl <mcepl@suse.com>
- Add skip_resource.setrlimit.patch to avoid tests failing in the limit
  environment of osc build, where resource.setrlimit() doesn't work
  (lp#1883125).
* Thu Aug 27 2020 Antonio Larrosa <alarrosa@suse.com>
- Patches from upstream to build with Dulwich 0.20.5:
  * 7551_7550.diff
  * 0001-Fix-tests-with-newer-dulwich.patch
  * 0002-Fix-more-tests.patch
* Wed Jun 10 2020 pgajdos@suse.com
- version update to 3.1.0
  3.0.3
  Bug Fixes
  * ********
  * Don't throw an error attempting to read the parent of a ref.
    (Jelmer Vernooĳ)
  * Fix fast-exporting of symlinks on Python 3. (Jelmer Vernooĳ, #1851478)
  * Don't rely on private transport attribute in fast-import.
    (Jelmer Vernooĳ, #1854607)
  * Fix conversion of time_t to int on certain platforms (arm64, armhf,
    ppc64el). (Jelmer Vernooĳ)
  External Compatibility Breaks
  * ****************************
  * The ``brz init-repo`` command has been renamed to
    ``brz init-shared-repo`` to emphasize that it creates
    shared repositories rather than just any kind of repository.
    (Jelmer Vernooĳ)
  New Features
  * ***********
  * A new ``brz land`` command can merge merge proposals on Launchpad,
    GitHub and GitLab sites. (Jelmer Vernooĳ, #1816213)
  * The 'patch' command is now bundled with brz.
    Imported from bzrtools by Aaron Bentley. (Jelmer Vernooĳ)
  * The 'quilt' plugin, extracted from brz-debian, is now
    bundled. (Jelmer Vernooĳ)
  * A new ``calculate_revnos`` configuration option (defaults to enabled)
    can be used to disable revno display for branch formats that
    do not natively store revnos. This speeds up ``brz log`` on
    the Samba git branch by 33%%.
    (Jelmer Vernooĳ)
  * Directly read mtab rather than using psutil when trying to figure out
    filesystem types. This removes a dependency that not all users may
    have installed and speeds up import time since psutil brings in
    various other modules. (Jelmer Vernooĳ)
  * ``brz diff`` now has a --color argument that can write
    color diff output. This is based on the cdiff code in
    bzrtools by Aaron Bentley.
    (Jelmer Vernooĳ, #376594)
  * Information about tree references can now be updated on remote
    branches. (Jelmer Vernooĳ)
  * Warn the user when they attempt to use Breezy in a Subversion
    working copy. (Jelmer Vernooĳ)
  * Add a basic Mercurial plugin that mentions that .hg repositories
    are unsupported when the user attempts to access one.
    (Jelmer Vernooĳ)
  * The ``2a`` format now officially supports storing tree references.
    It always partially supported storing tree reference data,
    and would happily pull in tree reference data from other repository
    formats. (Jelmer Vernooĳ)
  * A new ``fossil`` plugin has been added that warns users when they
    attempt to access Fossil repositories.
    (Jelmer Vernooĳ, #1848821)
  * When pushing to Git repositories, symrefs are now followed.
    (Jelmer Vernooĳ, #1800393)
  * New ``brz clone`` command, which clones everything under
    a control directory. I.e. all colocated branches, like
    ``git clone``. (Jelmer Vernooĳ, #831939)
  * ``brz sprout`` is now an alias for ``brz branch``.
    (Jelmer Vernooĳ)
  * ``brz branch`` now accepts a ``-b`` flag with the
    name of the colocated branch to sprout.
    (Jelmer Vernooĳ, #1869977)
  * Add a ``breezy.__main__`` module so that
    ``python3 -m breezy`` works. (Jelmer Vernooĳ)
  Improvements
  * ***********
  .. Improvements to existing commands, especially improved performance
    or memory usage, or better results.
  * A new ``--commit-message`` option has been added to
    ``brz propose``, for hosting sites that support it.
    (Jelmer Vernooĳ)
  * Automatically upgrade to branch format 8 when setting branch references.
    (Jelmer Vernooĳ)
  * The ``ssh`` configuration variable can be used to set the default
    SSH implementation. (Jelmer Vernooĳ, #650757)
  * ``locks.steal_dead`` is now enabled by default.
    (Jelmer Vernooĳ, #220464)
  * The substitution variables for the ``change_editor`` configuration
    option are now "{old_path}" and "{new_path}" rather than "@old_path" and
    "@new_path". The former is more consistent with the way substitutions
    work in other configuration options. The old syntax is still supported.
    (Jelmer Vernooĳ, #708718)
  * The ``brz inventory`` command now accepts a ``--include-root``
    argument to show the tree root. (Jelmer Vernooĳ)
  * Fix support for reading Git repositories over HTTP without
    a smart server. (Jelmer Vernooĳ)
  * CVS pserver URLs now indicate that the pserver protocol is not
    supported. (Jelmer Vernooĳ)
  * Git repositories with submodules can now be imported into 2a
    branches; submodules are converted to nested trees.
    (Jelmer Vernooĳ, #402814)
  * Python 3 is now used by default to run scripts, etc. from the makefile.
    (Jelmer Vernooĳ)
  * ``.git/config`` is now consulted to determine the users' identity
    for commits, and the gpg_signing_key. (Jelmer Vernooĳ)
  * Ignore special files (fifos, block/character devices, sockets)
    when finding changes in Git working trees. (Jelmer Vernooĳ, #1857244)
  * Parse error messages from stderr when a remote Git server
    hangs up. (Jelmer Vernooĳ)
  Bug Fixes
  * ********
  * Print a sensible error message when conversion for an option fails
    (i.e. when a non-int is specified as the value for an integer
    parameter) (#237844, Jelmer Vernooĳ)
  * Don't include timestamps in filenames when reporting on binary
    files in diff. (Jelmer Vernooĳ, #71307)
  * Ignore UnknownFormatErrors when scanning for control directories.
    (Jelmer Vernooĳ, #468332)
  * Fix fetching from remote git repositories in ``brz git-import``.
    (Jelmer Vernooĳ, #1836238)
  * A new ``TreeEntry.is_unmodified`` method has added, which allows
    merge to check for unmodified files without relying
    on the .revision attribute that is not available for Git trees.
    This fixes LCA merges for Git repositories.
    (Jelmer Vernooĳ, #1826663)
  * Fix passing of directories in specific_files to
    GitWorkingTree.iter_entries_by_dir(). (Jelmer Vernooĳ, #1844054)
  * Fix ``brz diff --using`` when {old_path} and {new_path} are not
    specified in the template. (#1847915, Jelmer Vernooĳ)
  * Ignore ghost tags when interacting with remote Git repositories.
    (Jelmer Vernooĳ)
  * Fix ``setup_ui=False`` when initializing Breezy.
    (Jelmer Vernooĳ, #1852647)
  * Fix backwards compatibility with Bazaar by supporting the
    $BZR_EMAIL variable. (Jelmer Vernooĳ, #1869178)
  * Cope with non-ascii characters in Git signatures.
    (Jelmer Vernooĳ, #1869533)
  * Fix use of ``proxy_bypass`` on Python 3.
    (Jelmer Vernooĳ, #1878698)
  * Create $XDG_HOME_DIR if it does not exist.
    (Jelmer Vernooĳ)
  API Changes
  * **********
  * New ``Tree.get_transform`` method for getting a ``TreeTransform``
    object. (Jelmer Vernooij)
  * The ``Tree.get_root_id`` method has been removed. Use
    ``Tree.path2id('')`` instead. (Jelmer Vernooĳ)
  * ``Repository.find_branches`` now returns an iterator rather than a
    list. (Jelmer Vernooĳ, #413970)
  * New ``Tree.get_nested_tree`` method for retrieving a nested tree.
    (Jelmer Vernooĳ)
  * The ``ControlDirFormat.register_server_prober`` method has been removed.
    Instead, probers can now have a ``priority`` method to influence
    when they are run. (Jelmer Vernooĳ)
  * New ``urlutils.strip_segment_parameters`` function for
    stripping segment parameters from a URL.
    (Jelmer Vernooĳ)
  * ``Tree.id2path`` has a new optional argument ``recurse``,
    that determines whether it scans through nested trees.
    (Jelmer Vernooĳ)
  * ``VersionedFiles.add_content`` can now be used to add
    content from ``ContentFactory`` objects.
    (Jelmer Vernooĳ)
- deleted patches
  - fix-tests.patch (upstreamed)
* Mon Jun  8 2020 Matej Cepl <mcepl@suse.com>
- Add 7531_7530.diff fixing handling of a particular kind of
  broken committer id (lp#1882589)
* Tue May 12 2020 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Disable test_ancient_{ctime,mtime} tests as they are known
  to be broken on aarch64 %%arm ppc ppc64le s390x
- Disable test_distant_{ctime,mtime} on %%arm
* Tue Apr  7 2020 Dominique Leuenberger <dimstar@opensuse.org>
- License: GPL-2.0-or-later. Updated as identified by legal review
  (info based on README.rst).
* Tue Mar 31 2020 Tomáš Chvátal <tchvatal@suse.com>
- Add provides/obsoletes on bzr as we are the py3 variant and
  provide the same binaries
* Tue Mar 31 2020 Tomáš Chvátal <tchvatal@suse.com>
- Add patch to fix borked test import fix-tests.patch
- Enable testing
* Wed Mar  4 2020 Antonio Larrosa <alarrosa@suse.com>
- Initial release of breezy 3.0.2 to replace bzr which only
  works with python2
